﻿<%@ Page Language="C#" %>
<%@ OutputCache  VaryByParam="type,id" Duration="1800" %>
<%@ Import Namespace="System.ServiceModel.Syndication" %>

<script runat="server">
    private int maxItems = 25; //max items to retrieve
    private long id = 0;
    private RssType rssType = RssType.TaxonomyRecursive;
    private enum RssType
    {
        Content,
        ContentRecursive,
        Taxonomy,
        TaxonomyRecursive
    }
    //will be used for the site url for the feed.
    private string baseUrl = "";
    //id of the metadata definition to look for (use id instead of text for language reasons)
    private long metaId = 0
    private string metavalue = "no"; //value to look for
    private bool returnmeta = false; //only set to true if you need to do some extra data processing that needs metadata
    
    
    protected void Page_Load(object sender, EventArgs e)
    {
        if (!String.IsNullOrEmpty(Request.QueryString["type"]))
        {
            switch (Request.QueryString["type"])
            {
                case "1":
                    rssType = RssType.Content;
                    break;
                case "2":
                    rssType = RssType.ContentRecursive;
                    break;
                case "3":
                    rssType = RssType.Taxonomy;
                    break;
                default:
                    break;
            }
        }
        if (!String.IsNullOrEmpty(Request.QueryString["id"]))
        {
            long.TryParse(Request.QueryString["id"], out id);
        }
        if (id > 0)
        {
            GetFeed();
        }
    }

    public void GetFeed()
    {
        // Code adapted from Steve Lautenschlager at CambiaResearch.com
        #region -- Create Feed --
        baseUrl = Request.Url.Scheme + "://" + Request.Url.Authority;
        //setup the properties below for your feed. 

        SyndicationFeed feed = new SyndicationFeed("Title", "Description", new Uri(baseUrl + "/pathtourl/"));
        feed.Copyright = new TextSyndicationContent("");
        feed.LastUpdatedTime = new DateTimeOffset(DateTime.Now);
        // add your site or feed logo url
        string imageUrl = baseUrl + "/images/logo-mobile.png";
        feed.ImageUrl = new Uri(imageUrl);

        // Add the URL that will link to your published feed when it's done
        SyndicationLink link = new SyndicationLink(new Uri(baseUrl + "/Rss/"));
        link.RelationshipType = "self";
        link.MediaType = "text/html";
        link.Title = "";
        feed.Links.Add(link);

        #endregion

        #region -- Loop over your content entries to add feed items --
        List<SyndicationItem> items = new List<SyndicationItem>();
        List<Ektron.Cms.ContentData> cData = new List<Ektron.Cms.ContentData>();
        switch (rssType)
        {
            case RssType.Taxonomy:
                cData = GetTaxonomyContent(false, returnmeta);
                break;
            case RssType.TaxonomyRecursive:
                cData = GetTaxonomyContent(true, returnmeta);
                break;
            case RssType.Content:
                cData = GetContent(false, returnmeta);
                break;
            case RssType.ContentRecursive:
                cData = GetContent(true, returnmeta);
                break;
            default:
                break;
        }
        if (returnmeta)
        {
            cData = MetaCheck(cData);
        }
        foreach (var cdItem in cData)
        {
            items.Add(BuildItem(cdItem));
        }
        feed.Items = items;
        Response.ContentType = "application/rss+xml";
        var feedWriter = System.Xml.XmlWriter.Create(Response.OutputStream);
        Rss20FeedFormatter rssFormatter = new Rss20FeedFormatter(feed);
        rssFormatter.WriteTo(feedWriter);
        feedWriter.Close();
        #endregion
    }

    private SyndicationItem BuildItem(Ektron.Cms.ContentData cData)
    {
        // create new entry for feed
        SyndicationItem item = new SyndicationItem();
        item.Id = cData.Id.ToString();
        // Add the URL for the item as a link
        var link = new SyndicationLink(new Uri(baseUrl + cData.Quicklink));
        item.Links.Add(link);
	item.AddPermalink(new Uri(baseUrl + cData.Quicklink));
        // Fill some properties for the item
        item.Title = new TextSyndicationContent(HttpContext.Current.Server.HtmlDecode(cData.Title));
        item.LastUpdatedTime = cData.DateModified;
        item.PublishDate = cData.DateCreated;
        item.Summary = new TextSyndicationContent(HttpContext.Current.Server.HtmlDecode(cData.Teaser), TextSyndicationContentKind.Html);
        // Finally add this item to the item collection
        return item;
            
    }
    
    /// <summary>
    /// use if needed to process some metadata for the content
    /// </summary>
    /// <returns></returns>
    private List<Ektron.Cms.ContentData> MetaCheck(List<Ektron.Cms.ContentData> cData)
    {
        List<Ektron.Cms.ContentData> contentData = new List<Ektron.Cms.ContentData>();
        foreach (var item in cData)
        {
            if (item.MetaData.FirstOrDefault(a => a.Id == metaId).Text.ToLower() == metavalue)
            {
                contentData.Add(item);
            }
        }
        return contentData;
    }
    
    private List<Ektron.Cms.ContentData> GetTaxonomyContent(bool recursive = false, bool returnmeta = false)
    {
        Ektron.Cms.Framework.Content.ContentManager cManager = new Ektron.Cms.Framework.Content.ContentManager();
        Ektron.Cms.Content.ContentTaxonomyCriteria criteria = new Ektron.Cms.Content.ContentTaxonomyCriteria();
        criteria.AddFilter(id, recursive); //get all nodes in taxonomy recursively
        criteria.PagingInfo = new Ektron.Cms.PagingInfo(maxItems);
        criteria.OrderByField = Ektron.Cms.Common.ContentProperty.DateCreated;
        if (returnmeta)
        {
            criteria.ReturnMetadata = true; //most cases this would be false but we need some extra checks here.         
        }
        return cManager.GetList(criteria);
        
    }
    private List<Ektron.Cms.ContentData> GetContent(bool recursive = false, bool returnmeta = false)
    {
        Ektron.Cms.Framework.Content.ContentManager cManager = new Ektron.Cms.Framework.Content.ContentManager();
        Ektron.Cms.Content.ContentCriteria criteria = new Ektron.Cms.Content.ContentCriteria();
        criteria.AddFilter(Ektron.Cms.Common.ContentProperty.FolderId, Ektron.Cms.Common.CriteriaFilterOperator.EqualTo, id);
        criteria.PagingInfo = new Ektron.Cms.PagingInfo(maxItems);
        criteria.OrderByField = Ektron.Cms.Common.ContentProperty.DateCreated;
        if (recursive)
        {
            criteria.FolderRecursive = true;
        }
        if (returnmeta)
        {
            criteria.ReturnMetadata = true;
        }
        return cManager.GetList(criteria);
    }
    
</script>

